@@ -967,7 +967,7 @@ class Line(ModelSQL, ModelView):
     def search_move_field(self, cursor, user, name, clause, context=None):
         if name == 'move_state':
             name = 'state'
-        return [('move.' + name,) + clause[1:]]
+        return [('move.' + name,) + tuple(clause[1:])]
 
     def query_get(self, cursor, user, obj='l', context=None):
         '''
